@@ -7,6 +7,9 @@ library(dplyr)
 library(tidyr)
 library(purrr)
 
+## ----CRAN, eval = FALSE--------------------------------------------------
+#  install.packages("cutpointr")
+
 ## ------------------------------------------------------------------------
 library(cutpointr)
 data(suicide)
@@ -392,6 +395,11 @@ opt_cut %>%
     select(-boot) %>%
     unnest
 
+## ------------------------------------------------------------------------
+cutpointr(suicide, dsi, suicide, gender, metric = youden, silent = TRUE) %>% 
+    add_metric(list(ppv, npv)) %>% 
+    select(subgroup, optimal_cutpoint, youden, ppv, npv)
+
 ## ---- eval = FALSE-------------------------------------------------------
 #  mean_cut <- function(data, x, ...) {
 #      oc <- mean(data[[x]])
@@ -486,7 +494,7 @@ opt_cut %>%
 #  x_neg <- dat$x[dat$y == 0]
 #  bench_10000 <- microbenchmark::microbenchmark(
 #      cutpointr(dat, x, y, pos_class = 1, neg_class = 0,
-#                direction = ">=", metric = youden, break_ties = mean),
+#                direction = ">=", metric = youden, break_ties = mean, silent = TRUE),
 #      rocr_sensspec(dat$x, dat$y),
 #      optimal.cutpoints(X = "x", status = "y", tag.healthy = 0, methods = "Youden",
 #                        data = dat),
@@ -554,13 +562,13 @@ opt_cut %>%
 ## ---- echo = FALSE-------------------------------------------------------
 # dput(results)
 
-results <- structure(list(time = c(25.0947145, 3.2099195, 8.8912175, 47.844527, 
-59.8605805, 29.0135295, 10.1589445, 5194.4737685, 83.2376275, 
-8252.99037, 85.9415705, 109.492256, 939.500229, 617.2541755, 
-1117.249976, 5906.549361, 13565.7166595), solution = c("cutpointr", 
-"ROCR", "pROC", "OptimalCutpoints", "ThresholdROC", "cutpointr", 
-"ROCR", "OptimalCutpoints", "pROC", "ThresholdROC", "cutpointr", 
-"ROCR", "pROC", "cutpointr", "ROCR", "cutpointr", "ROCR"), n = c(1000, 
+results <- structure(list(time = c(8.3344635, 3.0178925, 9.1314925, 56.2119325, 
+78.8832165, 13.057035, 11.284935, 5383.765367, 94.4034445, 7930.9735595, 
+68.155645, 108.9886265, 1021.0981875, 708.1933595, 1250.4259705, 
+5893.323971, 13247.3814165), solution = c("cutpointr", "ROCR", 
+"pROC", "OptimalCutpoints", "ThresholdROC", "cutpointr", "ROCR", 
+"OptimalCutpoints", "pROC", "ThresholdROC", "cutpointr", "ROCR", 
+"pROC", "cutpointr", "ROCR", "cutpointr", "ROCR"), n = c(1000, 
 1000, 1000, 1000, 1000, 10000, 10000, 10000, 10000, 10000, 1e+05, 
 1e+05, 1e+05, 1e+06, 1e+06, 1e+07, 1e+07)), .Names = c("time", 
 "solution", "n"), row.names = c(NA, -17L), class = "data.frame")
